==> camel-karavan-4.10.2.zip: camel-karavan-4.10.2/karavan-app/src/main/java/org/apache/camel/karavan/model/DockerCompose.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.karavan.model;

import java.util.HashMap;
import java.util.Map;

public class DockerCompose {
    private String version;
    private Map<String, DockerComposeService> services;
    private Map<String, DockerComposeNetwork> networks;

    public DockerCompose() {
    }

    public DockerCompose(Map<String, DockerComposeService> services) {
        this.services = services;
    }

    public static DockerCompose create(DockerComposeService service) {
        Map<String, DockerComposeService> map = new HashMap<>();
        map.put(service.getContainer_name(), service);
        return new DockerCompose(map);
    }

    public Map<String, DockerComposeService> getServices() {
        return services;
    }

    public void setServices(Map<String, DockerComposeService> services) {
        this.services = services;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public Map<String, DockerComposeNetwork> getNetworks() {
        return networks;
    }

    public void setNetworks(Map<String, DockerComposeNetwork> networks) {
        this.networks = networks;
    }
}

==> camel-karavan-4.14.2.zip: camel-karavan-4.14.2/karavan-app/src/main/java/org/apache/camel/karavan/model/DockerCompose.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.karavan.model;

import java.util.HashMap;
import java.util.Map;

public class DockerCompose {
    private String version;
    private Map<String, DockerComposeService> services;
    private Map<String, DockerNetworkDefinition> networks;

    public DockerCompose() {
    }

    public DockerCompose(Map<String, DockerComposeService> services) {
        this.services = services;
    }

    public static DockerCompose create(DockerComposeService service) {
        Map<String, DockerComposeService> map = new HashMap<>();
        map.put(service.getContainer_name(), service);
        return new DockerCompose(map);
    }

    public Map<String, DockerComposeService> getServices() {
        return services;
    }

    public void setServices(Map<String, DockerComposeService> services) {
        this.services = services;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public Map<String, DockerNetworkDefinition> getNetworks() {
        return networks;
    }

    public void setNetworks(Map<String, DockerNetworkDefinition> networks) {
        this.networks = networks;
    }
}
